==> openshift-model-config-6.8.0-sources.jar: io/fabric8/openshift/api/model/config/v1/HTPasswdIdentityProviderFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTPasswdIdentityProviderFluent<A extends HTPasswdIdentityProviderFluent<A>> extends BaseFluent<A>{
  public HTPasswdIdentityProviderFluent() {
  }
  public HTPasswdIdentityProviderFluent(HTPasswdIdentityProvider instance) {
    instance = (instance != null ? instance : new HTPasswdIdentityProvider());

    if (instance != null) {
      this.withFileData(instance.getFileData());
      this.withFileData(instance.getFileData());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private SecretNameReferenceBuilder fileData;
  private Map<String,Object> additionalProperties;
  public SecretNameReference buildFileData() {
    return this.fileData!=null ?this.fileData.build():null;
  }
  public A withFileData(SecretNameReference fileData) {
    _visitables.get("fileData").remove(this.fileData);
    if (fileData!=null){ this.fileData= new SecretNameReferenceBuilder(fileData); _visitables.get("fileData").add(this.fileData);} else { this.fileData = null; _visitables.get("fileData").remove(this.fileData); } return (A) this;
  }
  public boolean hasFileData() {
    return this.fileData != null;
  }
  public A withNewFileData(String name) {
    return (A)withFileData(new SecretNameReference(name));
  }
  public FileDataNested<A> withNewFileData() {
    return new FileDataNested(null);
  }
  public FileDataNested<A> withNewFileDataLike(SecretNameReference item) {
    return new FileDataNested(item);
  }
  public FileDataNested<A> editFileData() {
    return withNewFileDataLike(java.util.Optional.ofNullable(buildFileData()).orElse(null));
  }
  public FileDataNested<A> editOrNewFileData() {
    return withNewFileDataLike(java.util.Optional.ofNullable(buildFileData()).orElse(new SecretNameReferenceBuilder().build()));
  }
  public FileDataNested<A> editOrNewFileDataLike(SecretNameReference item) {
    return withNewFileDataLike(java.util.Optional.ofNullable(buildFileData()).orElse(item));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTPasswdIdentityProviderFluent that = (HTPasswdIdentityProviderFluent) o;
    if (!java.util.Objects.equals(fileData, that.fileData)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fileData,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (fileData != null) { sb.append("fileData:"); sb.append(fileData + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class FileDataNested<N> extends SecretNameReferenceFluent<FileDataNested<N>> implements Nested<N>{
    FileDataNested(SecretNameReference item) {
      this.builder = new SecretNameReferenceBuilder(this, item);
    }
    SecretNameReferenceBuilder builder;
    public N and() {
      return (N) HTPasswdIdentityProviderFluent.this.withFileData(builder.build());
    }
    public N endFileData() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.9.0-sources.jar: io/fabric8/openshift/api/model/config/v1/HTPasswdIdentityProviderFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class HTPasswdIdentityProviderFluent<A extends HTPasswdIdentityProviderFluent<A>> extends BaseFluent<A>{
  public HTPasswdIdentityProviderFluent() {
  }
  
  public HTPasswdIdentityProviderFluent(HTPasswdIdentityProvider instance) {
    this.copyInstance(instance);
  }
  private SecretNameReferenceBuilder fileData;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(HTPasswdIdentityProvider instance) {
    instance = (instance != null ? instance : new HTPasswdIdentityProvider());
  
    if (instance != null) {
        this.withFileData(instance.getFileData());
        this.withFileData(instance.getFileData());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public SecretNameReference buildFileData() {
    return this.fileData!=null ?this.fileData.build():null;
  }
  
  public A withFileData(SecretNameReference fileData) {
    _visitables.get("fileData").remove(this.fileData);
    if (fileData!=null){ this.fileData= new SecretNameReferenceBuilder(fileData); _visitables.get("fileData").add(this.fileData);} else { this.fileData = null; _visitables.get("fileData").remove(this.fileData); } return (A) this;
  }
  
  public boolean hasFileData() {
    return this.fileData != null;
  }
  
  public A withNewFileData(String name) {
    return (A)withFileData(new SecretNameReference(name));
  }
  
  public FileDataNested<A> withNewFileData() {
    return new FileDataNested(null);
  }
  
  public FileDataNested<A> withNewFileDataLike(SecretNameReference item) {
    return new FileDataNested(item);
  }
  
  public FileDataNested<A> editFileData() {
    return withNewFileDataLike(java.util.Optional.ofNullable(buildFileData()).orElse(null));
  }
  
  public FileDataNested<A> editOrNewFileData() {
    return withNewFileDataLike(java.util.Optional.ofNullable(buildFileData()).orElse(new SecretNameReferenceBuilder().build()));
  }
  
  public FileDataNested<A> editOrNewFileDataLike(SecretNameReference item) {
    return withNewFileDataLike(java.util.Optional.ofNullable(buildFileData()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTPasswdIdentityProviderFluent that = (HTPasswdIdentityProviderFluent) o;
    if (!java.util.Objects.equals(fileData, that.fileData)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(fileData,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (fileData != null) { sb.append("fileData:"); sb.append(fileData + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class FileDataNested<N> extends SecretNameReferenceFluent<FileDataNested<N>> implements Nested<N>{
    FileDataNested(SecretNameReference item) {
      this.builder = new SecretNameReferenceBuilder(this, item);
    }
    SecretNameReferenceBuilder builder;
    
    public N and() {
      return (N) HTPasswdIdentityProviderFluent.this.withFileData(builder.build());
    }
    
    public N endFileData() {
      return and();
    }
    
  
  }

}
